@@ -2,11 +2,12 @@
 # SPDX-FileCopyrightText: 2023-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
+from __future__ import annotations
 
 from playwright.sync_api import Locator, Page, expect
 
 from univention.lib.i18n import Translation
-from univention.testing.browser.lib import UMCBrowserTest
+from univention.testing.browser.lib import UMCBrowserTest  # noqa: TC001
 
 
 _ = Translation('ucs-test-framework').translate
