@@ -1,11 +1,7 @@
 #!/usr/bin/python3
-#
-# -*- coding: utf-8 -*-
-#
 # SPDX-FileCopyrightText: 2023-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
-from __future__ import annotations
 
 import shutil
 from typing import TextIO
